Method: Authlogic::Session::Validation#attempted_record
- Defined in:
- lib/authlogic/session/validation.rb
#attempted_record ⇒ Object
You should use this as a place holder for any records that you find during validation. The main reason for this is to allow other modules to use it if needed. Take the failed_login_count feature, it needs this in order to increase the failed login count.
28 29 30 |
# File 'lib/authlogic/session/validation.rb', line 28 def attempted_record @attempted_record end |